@@ -187,7 +187,7 @@ class oracletools:
             from dba_tab_cols where owner = ? and table_name = ? and column_name not like '%$%' order by column_id
         '''
         tab = ''
-        cols_ = db.run(sql, (user, table))["rows"]
+        cols_ = db.run(sql, (user, table)).getRows()
         lenNum = 0
         for col_ in cols_:
             if lenNum < len(col_[0]):
@@ -224,7 +224,7 @@ class oracletools:
                 end column_type
             from dba_tab_cols where owner = ? and table_name = ? and column_name not like '%$%' order by column_id
         '''
-        for r in db.run(sql, (user, table))["rows"]:
+        for r in db.run(sql, (user, table)).getRows():
             rssqls.append('alter table ' + user + '.' + table + ' add ' + r[0] + ' ' + r[1].strip())
         rssqls.append('alter table ' + user + '.' + table + ' drop column test_col')
         # 建主键
@@ -238,7 +238,7 @@ class oracletools:
             and t.constraint_type = 'P'
             group by t.constraint_name
         '''
-        for r in db.run(sql, (user, table))["rows"]:
+        for r in db.run(sql, (user, table)).getRows():
             rssqls.append('alter table ' + user + '.' + table + ' add constraint ' + r[0] + ' primary key(' + r[1] + ')')
         # 建非空约束
         sql = '''
@@ -251,7 +251,7 @@ class oracletools:
             and t.constraint_type = 'C'
             and t.search_condition is not null
         '''
-        for r in db.run(sql, (user, table))["rows"]:
+        for r in db.run(sql, (user, table)).getRows():
             if 'IS NOT NULL' in r[0]:
                 col = r[0].split(' ')[0]
                 rssqls.append('alter table ' + user + '.' + table + ' modify ' + col + ' not null')
@@ -266,7 +266,7 @@ class oracletools:
             and t.constraint_type = 'U'
             group by t.constraint_name
         '''
-        for r in db.run(sql, (user, table))["rows"]:
+        for r in db.run(sql, (user, table)).getRows():
             rssqls.append('alter table ' + user + '.' + table + ' add constraint ' + r[0] + ' unique(' + r[1] + ')')
         # 建默认值
         sql = '''
@@ -277,7 +277,7 @@ class oracletools:
             and column_name not like '%$%'
             and data_default is not null
         '''
-        for r in db.run(sql, (user, table))["rows"]:
+        for r in db.run(sql, (user, table)).getRows():
             rssqls.append('alter table ' + user + '.' + table + ' modify ' + r[0] + ' default ' + r[1].strip())
         # 建普通索引
         sql = '''
@@ -291,7 +291,7 @@ class oracletools:
             and t.index_type = 'NORMAL'
             group by t.index_name
         '''
-        for r in db.run(sql, (user, table))["rows"]:
+        for r in db.run(sql, (user, table)).getRows():
             rssqls.append('create index ' + user + '.' + r[0] + ' on ' + user + '.' + table + '(' + r[1] + ')')
         # 建函数索引
         sql = '''
@@ -309,7 +309,7 @@ class oracletools:
         col, rows = db.run(sql, (user, table))
         mdb = MemoryDB()
         mdb.set('t_idx', col, rows)
-        rs = mdb.db.run('select index_name, group_concat(column_expression) from t_idx group by index_name')["rows"]
+        rs = mdb.db.run('select index_name, group_concat(column_expression) from t_idx group by index_name').getRows()
         mdb.close()
         for r in rs:
             rssqls.append('create index ' + user + '.' + r[0] + ' on ' + user + '.' + table + '(' + r[1] + ')')
@@ -321,7 +321,7 @@ class oracletools:
             and table_name = ? 
             and comments is not null
         '''
-        for r in db.run(sql, (user, table))["rows"]:
+        for r in db.run(sql, (user, table)).getRows():
             rssqls.append("comment on column " + user + "." + table + "." + r[0] + " is '" + r[1] + "'")
         # 建外键
         pass
@@ -337,7 +337,7 @@ class oracletools:
                 dbms_metadata.get_ddl('TABLE', ?, ?)
             ) from dual
         '''
-        return db.run(sql, (table, user))["rows"][0]
+        return db.run(sql, (table, user)).getRows()[0]
     
     @staticmethod
     def compare_table(srcdb, srcuser, dstdb, dstuser):
@@ -347,7 +347,7 @@ class oracletools:
         out = ''
         tablist = []
         sql = 'select table_name from dba_tables where owner = ?'
-        srctabs = srcdb.run(sql, (srcuser,))["rows"]
+        srctabs = srcdb.run(sql, (srcuser,)).getRows()
         for tab in srctabs:
             srcdesc = oracletools.desc(srcdb, srcuser, tab[0])
             dstdesc = oracletools.desc(dstdb, dstuser, tab[0])
